@@ -1,4 +1,5 @@
 require 'telesign'
+require_relative 'constants'
 
 module TelesignEnterprise
 
@@ -9,12 +10,18 @@ module TelesignEnterprise
     def initialize(customer_id,
                    api_key,
                    rest_endpoint: 'https://rest-ww.telesign.com',
-                   timeout: nil)
+                   timeout: nil,
+                   source: 'ruby_telesign_enterprise',
+                   sdk_version_origin: TelesignEnterprise::SDK_VERSION,
+                   sdk_version_dependency: Gem.loaded_specs['telesign'].version)
 
       super(customer_id,
             api_key,
             rest_endpoint: rest_endpoint,
-            timeout: timeout)
+            timeout: timeout,
+            source: source,
+            sdk_version_origin: sdk_version_origin,
+            sdk_version_dependency: sdk_version_dependency)
     end
   end
 end
\ No newline at end of file
